==> nextcloud-31.0.8-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/ga.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "Foirne",
    "You created the team {circle}" : "Chruthaigh tú an fhoireann {circle}",
    "{author} created the team {circle}" : "Chruthaigh {author} an fhoireann {circle}",
    "You deleted {circle}" : "Scrios tú {circle}",
    "{author} deleted {circle}" : "Scrios {author} {ciorcal}",
    "You made {member} join {circle}" : "Rinne tú {ball} dul isteach i {circle}",
    "{author} made {member} join {circle}" : "Rinne {author} {member} dul isteach i {circle}",
    "You added team {member} as member to {circle}" : "Chuir tú foireann {member} mar bhall le {circle}",
    "{author} added team {member} as member to {circle}" : "Chuir {author} foireann {member} leis mar bhall le {circle}",
    "You made {member} leave {circle}" : "Rinne tú {ball} {circle} a fhágáil",
    "{author} made {member} leave {circle}" : "Rinne {author} {member} {circle} a fhágáil",
    "You removed {member} from {circle}" : "Bhain tú {member} de {circle}",
    "{author} removed {member} from {circle}" : "Bhain {author} {member} de {circle}",
    "You joined {circle}" : "Ghlac tú le {circle}",
    "{member} joined {circle}" : "Chuaigh {ball} isteach in {circle}",
    "You accepted the invitation to join {circle}" : "Ghlac tú leis an gcuireadh chun páirt a ghlacadh i {circle}",
    "{member} accepted the invitation to join {circle}" : "Ghlac {member} leis an gcuireadh páirt a ghlacadh i {circle}",
    "You added {member} as member to {circle}" : "Chuir tú {member} mar bhall le {circle}",
    "You have been added as member to {circle} by {author}" : "Chuir {author} le {circle} thú mar bhall",
    "{member} has been added as member to {circle} by {author}" : "Chuir {author} {member} le {circle} mar bhall",
    "You added {external} to {circle}" : "Chuir tú {external} le {circle}",
    "{external} has been added to {circle} by {author}" : "Tá {external} curtha le {circle} ag {author}",
    "You accepted {member}'s request to join {circle}" : "Ghlac tú le hiarratas {member} chun páirt a ghlacadh i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Ghlac {author} le d'iarratas chun páirt a ghlacadh i {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Ghlac {author} le hiarratas {member} chun páirt a ghlacadh in {circle}",
    "You left {circle}" : "D'fhág tú {circle}",
    "{member} left {circle}" : "D'fhág {ball} {circle}",
    "You declined the invitation to join {circle}" : "Dhiúltaigh tú an cuireadh chun páirt a ghlacadh i {circle}",
    "{member} declined an invitation to join {circle}" : "Dhiúltaigh {member} cuireadh chun páirt a ghlacadh i {circle}",
    "You cancelled your request to join {circle}" : "Chealaigh tú d'iarratas chun páirt a ghlacadh i {circle}",
    "{member} cancelled a request to join {circle}" : "Chealaigh {member} iarratas chun páirt a ghlacadh in {circle}",
    "You have been removed from {circle} by {author}" : "Bhain {author} de {circle} thú",
    "{member} has been removed from {circle} by {author}" : "Baineadh {member} de {circle} ag {author}",
    "You removed {external} from {circle}" : "Bhain tú {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "Bhain {author} {external} de {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Chealaigh tú cuireadh {member} páirt a ghlacadh in {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tá do chuireadh chun páirt a ghlacadh in {circle} curtha ar ceal ag {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "Thug tú cuireadh do {member} páirt a ghlacadh i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Dhiúltaigh tú iarratas {member} chun páirt a ghlacadh i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Dhiúltaigh {author} d'iarratas chun páirt a ghlacadh in {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Chuir {author} iarratas {member} chun páirt a ghlacadh in {circle}",
    "You invited {member} to join {circle}" : "Thug tú cuireadh do {member} páirt a ghlacadh sa {circle}",
    "You have been invited to join {circle} by {author}" : "Thug {author} cuireadh duit páirt a ghlacadh i {circle}",
    "{member} has been invited to join {circle} by {author}" : "Thug {author} cuireadh do {member} páirt a ghlacadh in {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "D'athraigh tú leibhéal {ball} i {circle} go %1$s",
    "{author} changed your level in {circle} to %1$s" : "D'athraigh {author} do leibhéal i {circle} go %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "D'athraigh {author} leibhéal {member} i {circle} go %1$s",
    "You sent a request to join {circle}" : "Sheol tú iarratas chun páirt a ghlacadh i {circle}",
    "{member} sent a request to join {circle}" : "Sheol {member} iarratas chun páirt a ghlacadh i {circle}",
    "You are the new owner of {circle}" : "Is úinéir nua thú ar {circle}",
    "{member} is the new owner of {circle}" : "Is é {member} úinéir nua {circle}",
    "On events happening in a <strong>team</strong> of which you are a member" : "Ar imeachtaí atá ar siúl i  <strong>bhfoireann</strong>a bhfuil tú i do bhall di",
    "Any important event in a <strong>team</strong> you are moderating" : "Imeacht thábhachtach ar bith i <strong>bhfoireann</strong> a bhfuil tú ag modhnú ",
    "On global events happening in any <strong>team</strong>" : "Ar imeachtaí domhanda ag tarlú in aon <strong>1fhoireann</strong>",
    "Single" : "Aonair",
    "Personal" : "Pearsanta",
    "System" : "Córas",
    "Visible" : "Infheicthe",
    "Open" : "Oscail",
    "Invite" : "Cuireadh",
    "Join request" : "Iarratas ar bheith páirteach",
    "Friends" : "Cairde",
    "Password protected" : "Pasfhocal cosanta",
    "No Owner" : "Gan Úinéir",
    "Hidden" : "I bhfolach",
    "Backend" : "Inneall",
    "Local" : "Áitiúil",
    "Root" : "Fréamh",
    "Team invite" : "Cuireadh foirne",
    "Federated" : "Cónaidhme",
    "Mount point" : "Pointe gléasta",
    "Nextcloud Account" : "Cuntas Nextcloud",
    "Nextcloud Group" : "Grúpa Nextcloud",
    "Email address" : "Seoladh ríomhphoist",
    "Contact" : "Teagmháil",
    "Circle" : "Ciorcal",
    "Nextcloud App" : "Aip Nextcloud",
    "Member" : "Ball",
    "Moderator" : "Modhnóir",
    "Admin" : "Riarachán",
    "Owner" : "Úinéir",
    "%s shared »%s« with you." : "%s roinn »%s« leat.",
    "%s shared »%s« with \"%s\"." : "%s roinn »%s« le \"%s\".",
    "%s on %s" : "%s ar %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s roinn »%2$s« leat.\nBa cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.\n\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s roinn »%2$s« leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.",
    "Password to access »%1$s« shared to you by %2$s" : "Tá pasfhocal chun rochtain a fháil ar »%1$s« roinnte agat ag %2$s",
    "Password to access »%s«" : "Pasfhocal le rochtain »%s«",
    "It is protected with the following password:" : "Tá sé cosanta leis an bhfocal faire seo a leanas:",
    "%1$s via %2$s" : "%1$s trí %2$s",
    "Click the button below to open it." : "Cliceáil ar an gcnaipe thíos chun é a oscailt.",
    "Open »%s«" : "Oscail »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "Roinn %1$s comhaid iolracha leat.\nBa cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun rochtain a fháil orthu.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "Roinn %1$s comhaid iolracha leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun rochtain a fháil orthu.",
    "Password to access files shared to you by %1$s" : "Pasfhocal chun rochtain a fháil ar chomhaid arna roinnt leat le %1$s",
    "Password to access files" : "Pasfhocal chun comhaid a rochtain",
    "%s shared multiple files with \"%s\"." : "Roinn %s comhaid iolracha le \"%s\".",
    "%s shared multiple files with you." : "Roinn %s comhaid iolracha leat.",
    "Boot up" : "Tosaithe suas",
    "Nextcloud Initialization" : "Túsú Nextcloud",
    "Circles App Initialization" : "Ciorcail Aip Tosaigh",
    "Fresh installation status" : "Stádas suiteála úr",
    "Building Local Database" : "Bunachar Sonraí Áitiúil a Thógáil",
    "Testing Basic Circle Creation" : "Cruthú Bunúsach Ciorcail a Thástáil",
    "Adding local users and moderators" : "Ag cur úsáideoirí áitiúla agus modhnóirí leis",
    "Show all teams" : "Taispeáin gach foireann",
    "Create a new team" : "Cruthaigh foireann nua",
    "Files" : "Comhaid",
    "This feature is not available for personal circles" : "Níl an ghné seo ar fáil do chiorcail phearsanta",
    "The team is not federated" : "Níl an fhoireann cónaidhmthe",
    "You cannot join this team" : "Ní féidir leat dul isteach san fhoireann seo",
    "This member is not a moderator" : "Ní modhnóir é an ball seo",
    "Insufficient privileges" : "Pribhléidí neamhleor",
    "This member does not exist" : "Níl an ball seo ann",
    "This member is the owner of the team" : "Is é an ball seo úinéir na foirne",
    "Level cannot be changed for this type of member" : "Ní féidir an leibhéal a athrú don chineál seo ball",
    "You are already a member of this circle" : "Tá tú i do bhall den chiorcal seo cheana féin",
    "You have been blocked from this circle" : "Cuireadh bac ort ón gciorcal seo",
    "The account is already a member of this circle" : "Tá an cuntas ina bhall den chiorcal seo cheana féin",
    "The account has already been invited into this circle" : "Tugadh cuireadh don chuntas sa chiorcal seo cheana féin",
    "%s (Team owned by %s)" : "%s (Foireann faoi úinéireacht %s)",
    "You are now a member of the Team \"%2$s\"" : "Tá tú i do bhall den Fhoireann anois \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Thug%1$s cuireadh duit dul isteach san Fhoireann \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s chuir sé iarratas isteach chun bheith mar bhall den Fhoireann \"%2$s\"",
    "Accept" : "Glac",
    "Refuse" : "Diúltaigh",
    "Leave the team" : "Fág an fhoireann",
    "%s" : "%s",
    "Personal team" : "Foireann phearsanta",
    "%s owned by %s" : "%s ar úinéireacht ag %s",
    "You have no permission to create a new team" : "Níl aon chead agat foireann nua a chruthú",
    "%s shared a file with \"%s\"." : "Roinn %s comhad le \"%s\".",
    "%s shared a file with you." : "Roinn%s comhad leat.",
    "Open %s" : "Oscailte %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "Roinn %1$s roinnt ábhair leat.\nBa cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "Roinn %1$s roinnt ábhair leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.",
    "Password to access content shared with you by %1$s" : "Pasfhocal chun rochtain a fháil ar ábhar atá roinnte leat faoi %1$s",
    "Password to access content" : "Pasfhocal chun rochtain a fháil ar ábhar",
    "This item is already shared with this team" : "Tá an mhír seo roinnte leis an bhfoireann seo cheana féin",
    "Bring cloud-users closer together." : "Tabhair na scamall-úsáideoirí níos gaire dá chéile.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Ligeann foirne do dhaoine a ngrúpaí daoine/comhghleacaithe/cairde féin a chruthú.\nIs féidir leis na grúpaí daoine sin a úsáid ansin ag aon aip eile chun críche comhroinnte.",
    "No files in here" : "Níl aon chomhaid istigh anseo",
    "No entries found in this folder" : "Níor aimsíodh aon iontrálacha san fhillteán seo",
    "Name" : "Ainm",
    "Size" : "Méid",
    "Modified" : "Athraithe",
    "Teams' files" : "Comhaid na bhfoirne",
    "Select team to filter by" : "Roghnaigh foireann le scagadh de réir",
    "No teams found" : "Níor aimsíodh foirne",
    "Please select teams to filter by" : "Roghnaigh foirne lena scagadh le do thoil",
    "No files found for the selected teams" : "Níor aimsíodh aon chomhaid do na foirne roghnaithe",
    "Shared to Circles" : "Roinnte go Ciorcail"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/ga.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "Chruthaigh tú an fhoireann {circle}",
    "{author} created the team {circle}" : "Chruthaigh {author} an fhoireann {circle}",
    "You deleted {circle}" : "Scrios tú {circle}",
    "{author} deleted {circle}" : "Scrios {author} {ciorcal}",
    "You made {member} join {circle}" : "Rinne tú {ball} dul isteach i {circle}",
    "{author} made {member} join {circle}" : "Rinne {author} {member} dul isteach i {circle}",
    "You added team {member} as member to {circle}" : "Chuir tú foireann {member} mar bhall le {circle}",
    "{author} added team {member} as member to {circle}" : "Chuir {author} foireann {member} leis mar bhall le {circle}",
    "You made {member} leave {circle}" : "Rinne tú {ball} {circle} a fhágáil",
    "{author} made {member} leave {circle}" : "Rinne {author} {member} {circle} a fhágáil",
    "You removed {member} from {circle}" : "Bhain tú {member} de {circle}",
    "{author} removed {member} from {circle}" : "Bhain {author} {member} de {circle}",
    "You joined {circle}" : "Ghlac tú le {circle}",
    "{member} joined {circle}" : "Chuaigh {ball} isteach in {circle}",
    "You accepted the invitation to join {circle}" : "Ghlac tú leis an gcuireadh chun páirt a ghlacadh i {circle}",
    "{member} accepted the invitation to join {circle}" : "Ghlac {member} leis an gcuireadh páirt a ghlacadh i {circle}",
    "You added {member} as member to {circle}" : "Chuir tú {member} mar bhall le {circle}",
    "You have been added as member to {circle} by {author}" : "Chuir {author} le {circle} thú mar bhall",
    "{member} has been added as member to {circle} by {author}" : "Chuir {author} {member} le {circle} mar bhall",
    "You added {external} to {circle}" : "Chuir tú {external} le {circle}",
    "{external} has been added to {circle} by {author}" : "Tá {external} curtha le {circle} ag {author}",
    "You accepted {member}'s request to join {circle}" : "Ghlac tú le hiarratas {member} chun páirt a ghlacadh i {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Ghlac {author} le d'iarratas chun páirt a ghlacadh i {circle}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Ghlac {author} le hiarratas {member} chun páirt a ghlacadh in {circle}",
    "You left {circle}" : "D'fhág tú {circle}",
    "{member} left {circle}" : "D'fhág {ball} {circle}",
    "You declined the invitation to join {circle}" : "Dhiúltaigh tú an cuireadh chun páirt a ghlacadh i {circle}",
    "{member} declined an invitation to join {circle}" : "Dhiúltaigh {member} cuireadh chun páirt a ghlacadh i {circle}",
    "You cancelled your request to join {circle}" : "Chealaigh tú d'iarratas chun páirt a ghlacadh i {circle}",
    "{member} cancelled a request to join {circle}" : "Chealaigh {member} iarratas chun páirt a ghlacadh in {circle}",
    "You have been removed from {circle} by {author}" : "Bhain {author} de {circle} thú",
    "{member} has been removed from {circle} by {author}" : "Baineadh {member} de {circle} ag {author}",
    "You removed {external} from {circle}" : "Bhain tú {external} de {circle}",
    "{external} has been removed from {circle} by {author}" : "Bhain {author} {external} de {circle}",
    "You cancelled {member}'s invitation to join {circle}" : "Chealaigh tú cuireadh {member} páirt a ghlacadh in {circle}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Tá do chuireadh chun páirt a ghlacadh in {circle} curtha ar ceal ag {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "Thug tú cuireadh do {member} páirt a ghlacadh i {circle}",
    "You dismissed {member}'s request to join {circle}" : "Dhiúltaigh tú iarratas {member} chun páirt a ghlacadh i {circle}",
    "Your request to join {circle} has been dismissed by {author}" : "Dhiúltaigh {author} d'iarratas chun páirt a ghlacadh in {circle}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Chuir {author} iarratas {member} chun páirt a ghlacadh in {circle}",
    "You invited {member} to join {circle}" : "Thug tú cuireadh do {member} páirt a ghlacadh sa {circle}",
    "You have been invited to join {circle} by {author}" : "Thug {author} cuireadh duit páirt a ghlacadh i {circle}",
    "{member} has been invited to join {circle} by {author}" : "Thug {author} cuireadh do {member} páirt a ghlacadh in {circle}",
    "You changed {member}'s level in {circle} to %1$s" : "D'athraigh tú leibhéal {ball} i {circle} go %1$s",
    "{author} changed your level in {circle} to %1$s" : "D'athraigh {author} do leibhéal i {circle} go %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "D'athraigh {author} leibhéal {member} i {circle} go %1$s",
    "You sent a request to join {circle}" : "Sheol tú iarratas chun páirt a ghlacadh i {circle}",
    "{member} sent a request to join {circle}" : "Sheol {member} iarratas chun páirt a ghlacadh i {circle}",
    "You are the new owner of {circle}" : "Is úinéir nua thú ar {circle}",
    "{member} is the new owner of {circle}" : "Is é {member} úinéir nua {circle}",
    "Teams" : "Foirne",
    "On events happening in a <strong>team</strong> of which you are a member" : "Ar imeachtaí atá ar siúl i  <strong>bhfoireann</strong>a bhfuil tú i do bhall di",
    "Any important event in a <strong>team</strong> you are moderating" : "Imeacht thábhachtach ar bith i <strong>bhfoireann</strong> a bhfuil tú ag modhnú ",
    "On global events happening in any <strong>team</strong>" : "Ar imeachtaí domhanda ag tarlú in aon <strong>1fhoireann</strong>",
    "Single" : "Aonair",
    "Personal" : "Pearsanta",
    "System" : "Córas",
    "Visible" : "Infheicthe",
    "Open" : "Oscail",
    "Invite" : "Cuireadh",
    "Join request" : "Iarratas ar bheith páirteach",
    "Friends" : "Cairde",
    "Password protected" : "Pasfhocal cosanta",
    "No Owner" : "Gan Úinéir",
    "Hidden" : "I bhfolach",
    "Backend" : "Inneall",
    "Local" : "Áitiúil",
    "Root" : "Fréamh",
    "Team invite" : "Cuireadh foirne",
    "Federated" : "Cónaidhme",
    "Mount point" : "Pointe gléasta",
    "Nextcloud Account" : "Cuntas Nextcloud",
    "Nextcloud Group" : "Grúpa Nextcloud",
    "Email address" : "Seoladh ríomhphoist",
    "Contact" : "Teagmháil",
    "Team" : "Foireann",
    "Nextcloud App" : "Aip Nextcloud",
    "Teams App" : "Aip Foirne",
    "Admin Command Line" : "Líne Ordaithe Riarthóra",
    "Member" : "Ball",
    "Moderator" : "Modhnóir",
    "Admin" : "Riarachán",
    "Owner" : "Úinéir",
    "%s shared »%s« with you." : "%s roinn »%s« leat.",
    "%s shared »%s« with \"%s\"." : "%s roinn »%s« le \"%s\".",
    "%s on %s" : "%s ar %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s roinn »%2$s« leat.\nBa cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.\n\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$s roinn »%2$s« leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.",
    "Password to access »%1$s« shared to you by %2$s" : "Tá pasfhocal chun rochtain a fháil ar »%1$s« roinnte agat ag %2$s",
    "Password to access »%s«" : "Pasfhocal le rochtain »%s«",
    "It is protected with the following password:" : "Tá sé cosanta leis an bhfocal faire seo a leanas:",
    "%1$s via %2$s" : "%1$s trí %2$s",
    "Click the button below to open it." : "Cliceáil ar an gcnaipe thíos chun é a oscailt.",
    "Open »%s«" : "Oscail »%s«",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "Roinn %1$s comhaid iolracha leat.\nBa cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun rochtain a fháil orthu.\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "Roinn %1$s comhaid iolracha leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun rochtain a fháil orthu.",
    "Password to access files shared to you by %1$s" : "Pasfhocal chun rochtain a fháil ar chomhaid arna roinnt leat le %1$s",
    "Password to access files" : "Pasfhocal chun comhaid a rochtain",
    "%s shared multiple files with \"%s\"." : "Roinn %s comhaid iolracha le \"%s\".",
    "%s shared multiple files with you." : "Roinn %s comhaid iolracha leat.",
    "Boot up" : "Tosaithe suas",
    "Nextcloud Initialization" : "Túsú Nextcloud",
    "Circles App Initialization" : "Ciorcail Aip Tosaigh",
    "Fresh installation status" : "Stádas suiteála úr",
    "Building Local Database" : "Bunachar Sonraí Áitiúil a Thógáil",
    "Testing Basic Team Creation" : "Tástáil ar Chruthú Foirne Bunúsach",
    "Adding local users and moderators" : "Ag cur úsáideoirí áitiúla agus modhnóirí leis",
    "Show all teams" : "Taispeáin gach foireann",
    "Create a new team" : "Cruthaigh foireann nua",
    "Files" : "Comhaid",
    "This feature is not available for personal teams" : "Níl an ghné seo ar fáil do fhoirne pearsanta",
    "The team is not federated" : "Níl an fhoireann cónaidhmthe",
    "You cannot join this team" : "Ní féidir leat dul isteach san fhoireann seo",
    "This member is not a moderator" : "Ní modhnóir é an ball seo",
    "Insufficient privileges" : "Pribhléidí neamhleor",
    "This member does not exist" : "Níl an ball seo ann",
    "This member is the owner of the team" : "Is é an ball seo úinéir na foirne",
    "Level cannot be changed for this type of member" : "Ní féidir an leibhéal a athrú don chineál seo ball",
    "You are already a member of this team" : "Is ball den fhoireann seo thú cheana féin",
    "You have been blocked from this team" : "Tá bac curtha ort ón bhfoireann seo",
    "The account is already a member of this team" : "Tá an cuntas ina bhall den fhoireann seo cheana féin",
    "The account has already been invited into this team" : "Tá cuireadh tugtha don chuntas isteach sa fhoireann seo cheana féin",
    "%s (Team owned by %s)" : "%s (Foireann faoi úinéireacht %s)",
    "You are now a member of the Team \"%2$s\"" : "Tá tú i do bhall den Fhoireann anois \"%2$s\"",
    "You have been invited by %1$s into the Team \"%2$s\"" : "Thug%1$s cuireadh duit dul isteach san Fhoireann \"%2$s\"",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$s chuir sé iarratas isteach chun bheith mar bhall den Fhoireann \"%2$s\"",
    "Accept" : "Glac",
    "Refuse" : "Diúltaigh",
    "Leave the team" : "Fág an fhoireann",
    "%s" : "%s",
    "Personal team" : "Foireann phearsanta",
    "%s owned by %s" : "%s ar úinéireacht ag %s",
    "You have no permission to create a new team" : "Níl aon chead agat foireann nua a chruthú",
    "%s shared a file with \"%s\"." : "Roinn %s comhad le \"%s\".",
    "%s shared a file with you." : "Roinn%s comhad leat.",
    "%1$s shared %2$s with %3$s" : "%1$s roinnte %2$s le %3$s",
    "%1$s shared %2$s with \"%3$s\"" : "%1$s roinnte %2$s le \"%3$s\"",
    "Open %s" : "Oscailte %s",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "Roinn %1$s roinnt ábhair leat.\nBa cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "Roinn %1$s roinnt ábhair leat. Ba cheart go mbeadh ríomhphost ar leith faighte agat cheana féin le nasc chun é a rochtain.",
    "Password to access content shared with you by %1$s" : "Pasfhocal chun rochtain a fháil ar ábhar atá roinnte leat faoi %1$s",
    "Password to access content" : "Pasfhocal chun rochtain a fháil ar ábhar",
    "This item is already shared with this team" : "Tá an mhír seo roinnte leis an bhfoireann seo cheana féin",
    "Bring cloud-users closer together." : "Tabhair na scamall-úsáideoirí níos gaire dá chéile.",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "Ligeann foirne do dhaoine a ngrúpaí daoine/comhghleacaithe/cairde féin a chruthú.\nIs féidir leis na grúpaí daoine sin a úsáid ansin ag aon aip eile chun críche comhroinnte.",
    "Failed to load teams" : "Theip ar fhoirne a lódáil",
    "Try again" : "Déan iarracht arís",
    "No teams found" : "Níor aimsíodh foirne",
    "Join or create teams to see them here." : "Bígí páirteach nó cruthaigh foirne chun iad a fheiceáil anseo.",
    "Create your first team" : "Cruthaigh do chéad fhoireann",
    "Loading…" : "Á lódáil…",
    "More teams" : "Tuilleadh foirne",
    "No files in here" : "Níl aon chomhaid istigh anseo",
    "No entries found in this folder" : "Níor aimsíodh aon iontrálacha san fhillteán seo",
    "Name" : "Ainm",
    "Size" : "Méid",
    "Modified" : "Athraithe",
    "Shared to Circles" : "Roinnte go Ciorcail"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
